==> k4de-0.3.0.tgz: k4de-0.3.0/src/include/objects.h <==
/******************************************************************************
**                                                                           **
**    k4de - 3d-editor for the K Desktop Enviroment                          **
**                                                                           **
**    Copyright (C) 1999  Tobias Wollgam (tobias.wollgam@gmx.de)             **
**    Copyright (C) 1999  Markus Weber (mweber@gmx.de)                       **
**                                                                           **
**    This program is free software; you can redistribute it and/or modify   **
**    it under the terms of the GNU General Public License as published by   **
**    the Free Software Foundation; either version 2 of the License, or      **
**    (at your option) any later version.                                    **
**                                                                           **
**    This program is distributed in the hope that it will be useful,        **
**    but WITHOUT ANY WARRANTY; without even the implied warranty of         **
**    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the          **
**    GNU General Public License for more details.                           **
**                                                                           **
**    You should have received a copy of the GNU General Public License      **
**    along with this program; if not, write to the Free Software            **
**    Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.              **
**                                                                           **
******************************************************************************/
/*
** objects.h
*/
//#include "../3d/objects/poly.h"
//#include "../3d/objects/prism.h"
//#include "../3d/objects/quadric.h"
//#include "../3d/objects/quartic.h"
//#include "../3d/objects/superellipsoid.h"
//#include "../3d/objects/cubic.h"
//#include "../3d/objects/lathe.h"
#include "../3d/objects/triangle.h"
#include "../3d/objects/world.h"
#include "../3d/objects/obj.h"
#include "../3d/objects/ref.h"
#include "../3d/objects/refptr.h"
#include "../3d/objects/blob.h"
#include "../3d/objects/csg.h"
#include "../3d/objects/box.h"
#include "../3d/objects/sphere.h"
#include "../3d/objects/cylinder.h"
#include "../3d/objects/torus.h"
#include "../3d/objects/cone.h"
#include "../3d/objects/script.h"
#include "../3d/objects/text.h"
#include "../3d/objects/plane.h"
#include "../3d/objects/disc.h"
#include "../3d/objects/heightfield.h"
#include "../3d/objects/mesh.h"
#include "../3d/objects/cmesh.h"
#include "../3d/objects/camera.h"


#include "../3d/objects/lightpoint.h"
#include "../3d/objects/spotlight.h"
//#include "../3d/objects/arealight.h"

==> k4de-0.4.0.tgz: k4de-0.4.0/src/include/objects.h <==
/******************************************************************************
**                                                                           **
**    k4de - 3d-editor for the K Desktop Enviroment                          **
**                                                                           **
**    Copyright (C) 1999  Tobias Wollgam (tobias.wollgam@gmx.de)             **
**    Copyright (C) 1999  Markus Weber (mweber@gmx.de)                       **
**                                                                           **
**    This program is free software; you can redistribute it and/or modify   **
**    it under the terms of the GNU General Public License as published by   **
**    the Free Software Foundation; either version 2 of the License, or      **
**    (at your option) any later version.                                    **
**                                                                           **
**    This program is distributed in the hope that it will be useful,        **
**    but WITHOUT ANY WARRANTY; without even the implied warranty of         **
**    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the          **
**    GNU General Public License for more details.                           **
**                                                                           **
**    You should have received a copy of the GNU General Public License      **
**    along with this program; if not, write to the Free Software            **
**    Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.              **
**                                                                           **
******************************************************************************/
/*
** objects.h
*/


//#include "../3d/objects/mesh.h"

#include "../3d/objects/triangle.h"
#include "../3d/objects/world.h"
#include "../3d/objects/obj.h"
#include "../3d/objects/ref.h"
#include "../3d/objects/refptr.h"
#include "../3d/objects/blob.h"
#include "../3d/objects/csg.h"
#include "../3d/objects/box.h"
#include "../3d/objects/sphere.h"
#include "../3d/objects/cylinder.h"
#include "../3d/objects/torus.h"
#include "../3d/objects/cone.h"
#include "../3d/objects/script.h"
#include "../3d/objects/text.h"
#include "../3d/objects/plane.h"
#include "../3d/objects/disc.h"
#include "../3d/objects/heightfield.h"
#include "../3d/objects/cmesh.h"
#include "../3d/objects/smesh.h"
#include "../3d/objects/camera.h"
#include "../3d/objects/ear.h"


#include "../3d/objects/lightpoint.h"
#include "../3d/objects/spotlight.h"
//#include "../3d/objects/arealight.h"
